@@ -1,7 +1,7 @@
 package App::CSVUtils;
 
-our $DATE = '2016-11-17'; # DATE
-our $VERSION = '0.011'; # VERSION
+our $DATE = '2017-04-25'; # DATE
+our $VERSION = '0.012'; # VERSION
 
 use 5.010001;
 use strict;
@@ -161,6 +161,22 @@ my %arg_fields_1 = (
     },
 );
 
+my %arg_fields_or_field_pat = (
+    fields => {
+        'x.name.is_plural' => 1,
+        summary => 'Field names',
+        schema => ['array*', of=>'str*'],
+        cmdline_aliases => { F=>{} },
+        pos => 1,
+        greedy => 1,
+        element_completion => \&_complete_field,
+    },
+    field_pat => {
+        summary => 'Field regex pattern to select',
+        schema => 're*',
+    },
+);
+
 my %arg_eval_2 = (
     eval => {
         summary => 'Perl code to do munging',
@@ -420,9 +436,16 @@ sub csvutil {
             if (!defined($field_idxs)) {
                 $field_idxs = [];
                 my %seen;
-                for my $f (@{ $args{_fields} }) {
-                    return [400, "Duplicate field '$f'"] if $seen{$f}++;
-                    push @$field_idxs, _get_field_idx($f, \%field_idxs);
+                if ($args{_fields}) {
+                    for my $f (@{ $args{_fields} }) {
+                        return [400, "Duplicate field '$f'"] if $seen{$f}++;
+                        push @$field_idxs, _get_field_idx($f, \%field_idxs);
+                    }
+                } else {
+                    for my $f (@$fields) {
+                        next unless $f =~ $args{_field_pat};
+                        push @$field_idxs, $field_idxs{$f};
+                    }
                 }
             }
             $row = [map { $row->[$_] } @$field_idxs];
@@ -830,12 +853,16 @@ $SPEC{csv_select_fields} = {
     summary => 'Only output selected field(s)',
     args => {
         %arg_filename_0,
-        %arg_fields_1,
+        %arg_fields_or_field_pat,
+    },
+    args_rels => {
+        req_one => ['fields', 'field_pat'],
     },
 };
 sub csv_select_fields {
     my %args = @_;
-    csvutil(%args, action=>'select-fields', _fields => $args{fields});
+    csvutil(%args, action=>'select-fields',
+            _fields => $args{fields}, _field_pat => $args{field_pat});
 }
 
 1;
@@ -853,7 +880,7 @@ App::CSVUtils - CLI utilities related to CSV
 
 =head1 VERSION
 
-This document describes version 0.011 of App::CSVUtils (from Perl distribution App-CSVUtils), released on 2016-11-17.
+This document describes version 0.012 of App::CSVUtils (from Perl distribution App-CSVUtils), released on 2017-04-25.
 
 =head1 DESCRIPTION
 
@@ -890,7 +917,11 @@ This distribution contains the following CLI utilities:
 =head1 FUNCTIONS
 
 
-=head2 csv_add_field(%args) -> [status, msg, result, meta]
+=head2 csv_add_field
+
+Usage:
+
+ csv_add_field(%args) -> [status, msg, result, meta]
 
 Add a field to CSV file.
 
@@ -947,7 +978,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 csv_avg(%args) -> [status, msg, result, meta]
+=head2 csv_avg
+
+Usage:
+
+ csv_avg(%args) -> [status, msg, result, meta]
 
 Output a summary row which are arithmetic averages of data rows.
 
@@ -979,7 +1014,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 csv_concat(%args) -> [status, msg, result, meta]
+=head2 csv_concat
+
+Usage:
+
+ csv_concat(%args) -> [status, msg, result, meta]
 
 Concatenate several CSV files together, collecting all the fields.
 
@@ -1037,7 +1076,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 csv_convert_to_hash(%args) -> [status, msg, result, meta]
+=head2 csv_convert_to_hash
+
+Usage:
+
+ csv_convert_to_hash(%args) -> [status, msg, result, meta]
 
 Return a hash of field names as keys and first row as values.
 
@@ -1069,7 +1112,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 csv_delete_field(%args) -> [status, msg, result, meta]
+=head2 csv_delete_field
+
+Usage:
+
+ csv_delete_field(%args) -> [status, msg, result, meta]
 
 Delete one or more fields from CSV file.
 
@@ -1101,7 +1148,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 csv_list_field_names(%args) -> [status, msg, result, meta]
+=head2 csv_list_field_names
+
+Usage:
+
+ csv_list_field_names(%args) -> [status, msg, result, meta]
 
 List field names of CSV file.
 
@@ -1129,7 +1180,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 csv_munge_field(%args) -> [status, msg, result, meta]
+=head2 csv_munge_field
+
+Usage:
+
+ csv_munge_field(%args) -> [status, msg, result, meta]
 
 Munge a field in every row of CSV file.
 
@@ -1170,7 +1225,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 csv_replace_newline(%args) -> [status, msg, result, meta]
+=head2 csv_replace_newline
+
+Usage:
+
+ csv_replace_newline(%args) -> [status, msg, result, meta]
 
 Replace newlines in CSV values.
 
@@ -1206,7 +1265,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 csv_select_fields(%args) -> [status, msg, result, meta]
+=head2 csv_select_fields
+
+Usage:
+
+ csv_select_fields(%args) -> [status, msg, result, meta]
 
 Only output selected field(s).
 
@@ -1216,7 +1279,11 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<fields>* => I<array[str]>
+=item * B<field_pat> => I<re>
+
+Field regex pattern to select.
+
+=item * B<fields> => I<array[str]>
 
 Field names.
 
@@ -1238,7 +1305,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 csv_select_row(%args) -> [status, msg, result, meta]
+=head2 csv_select_row
+
+Usage:
+
+ csv_select_row(%args) -> [status, msg, result, meta]
 
 Only output specified row(s).
 
@@ -1270,7 +1341,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 csv_sort_fields(%args) -> [status, msg, result, meta]
+=head2 csv_sort_fields
+
+Usage:
+
+ csv_sort_fields(%args) -> [status, msg, result, meta]
 
 Sort CSV fields.
 
@@ -1306,7 +1381,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 csv_sum(%args) -> [status, msg, result, meta]
+=head2 csv_sum
+
+Usage:
+
+ csv_sum(%args) -> [status, msg, result, meta]
 
 Output a summary row which are arithmetic sums of data rows.
 
@@ -1363,7 +1442,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
